==> knative-model-6.7.1-sources.jar: io/fabric8/knative/internal/pkg/apis/duck/v1/KReferenceBuilder.java <==
package io.fabric8.knative.internal.pkg.apis.duck.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class KReferenceBuilder extends KReferenceFluentImpl<KReferenceBuilder> implements VisitableBuilder<KReference,KReferenceBuilder>{
  public KReferenceBuilder() {
    this(false);
  }
  public KReferenceBuilder(Boolean validationEnabled) {
    this(new KReference(), validationEnabled);
  }
  public KReferenceBuilder(KReferenceFluent<?> fluent) {
    this(fluent, false);
  }
  public KReferenceBuilder(KReferenceFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new KReference(), validationEnabled);
  }
  public KReferenceBuilder(KReferenceFluent<?> fluent,KReference instance) {
    this(fluent, instance, false);
  }
  public KReferenceBuilder(KReferenceFluent<?> fluent,KReference instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withGroup(instance.getGroup());
      fluent.withKind(instance.getKind());
      fluent.withName(instance.getName());
      fluent.withNamespace(instance.getNamespace());
    }
    this.validationEnabled = validationEnabled; 
  }
  public KReferenceBuilder(KReference instance) {
    this(instance,false);
  }
  public KReferenceBuilder(KReference instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withGroup(instance.getGroup());
      this.withKind(instance.getKind());
      this.withName(instance.getName());
      this.withNamespace(instance.getNamespace());
    }
    this.validationEnabled = validationEnabled; 
  }
  KReferenceFluent<?> fluent;
  Boolean validationEnabled;
  public KReference build() {
    KReference buildable = new KReference(fluent.getApiVersion(),fluent.getGroup(),fluent.getKind(),fluent.getName(),fluent.getNamespace());
    return buildable;
  }
  
}

==> knative-model-6.8.0-sources.jar: io/fabric8/knative/internal/pkg/apis/duck/v1/KReferenceBuilder.java <==
package io.fabric8.knative.internal.pkg.apis.duck.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class KReferenceBuilder extends KReferenceFluent<KReferenceBuilder> implements VisitableBuilder<KReference,KReferenceBuilder>{
  public KReferenceBuilder() {
    this(false);
  }
  public KReferenceBuilder(Boolean validationEnabled) {
    this(new KReference(), validationEnabled);
  }
  public KReferenceBuilder(KReferenceFluent<?> fluent) {
    this(fluent, false);
  }
  public KReferenceBuilder(KReferenceFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new KReference(), validationEnabled);
  }
  public KReferenceBuilder(KReferenceFluent<?> fluent,KReference instance) {
    this(fluent, instance, false);
  }
  public KReferenceBuilder(KReferenceFluent<?> fluent,KReference instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new KReference());

    if (instance != null) {
      fluent.withAddress(instance.getAddress());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withGroup(instance.getGroup());
      fluent.withKind(instance.getKind());
      fluent.withName(instance.getName());
      fluent.withNamespace(instance.getNamespace());
      fluent.withAddress(instance.getAddress());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withGroup(instance.getGroup());
      fluent.withKind(instance.getKind());
      fluent.withName(instance.getName());
      fluent.withNamespace(instance.getNamespace());
    }
    this.validationEnabled = validationEnabled; 
  }
  public KReferenceBuilder(KReference instance) {
    this(instance,false);
  }
  public KReferenceBuilder(KReference instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new KReference());

    if (instance != null) {
      this.withAddress(instance.getAddress());
      this.withApiVersion(instance.getApiVersion());
      this.withGroup(instance.getGroup());
      this.withKind(instance.getKind());
      this.withName(instance.getName());
      this.withNamespace(instance.getNamespace());
      this.withAddress(instance.getAddress());
      this.withApiVersion(instance.getApiVersion());
      this.withGroup(instance.getGroup());
      this.withKind(instance.getKind());
      this.withName(instance.getName());
      this.withNamespace(instance.getNamespace());
    }
    this.validationEnabled = validationEnabled; 
  }
  KReferenceFluent<?> fluent;
  Boolean validationEnabled;
  public KReference build() {
    KReference buildable = new KReference(fluent.getAddress(),fluent.getApiVersion(),fluent.getGroup(),fluent.getKind(),fluent.getName(),fluent.getNamespace());
    return buildable;
  }
  
}
